@@ -295,7 +295,7 @@ coxpenal.fit <- function(x, y, strata, offset, init, control,
                        as.integer(nvar), 
                        as.double(y),
                        x= as.double(xx) ,
-                       as.double(offset - mean(offset)),
+                       as.double(offset),
                        as.double(weights),
 		       as.integer(newstrat),
 		       as.integer(sorted-1),
